"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.unauthPostAsync = exports.postAsync = exports.putAsync = exports.getAsync = void 0;
const isomorphic_fetch_1 = __importDefault(require("isomorphic-fetch"));
const odspAuth_js_1 = require("./odspAuth.js");
/**
 * @internal
 */
async function getAsync(url, authRequestInfo) {
    return authRequest(authRequestInfo, async (config) => (0, isomorphic_fetch_1.default)(url, config));
}
exports.getAsync = getAsync;
/**
 * @internal
 */
async function putAsync(url, authRequestInfo) {
    return authRequest(authRequestInfo, async (config) => {
        const putConfig = {
            ...config,
            method: "PUT",
        };
        return (0, isomorphic_fetch_1.default)(url, putConfig);
    });
}
exports.putAsync = putAsync;
/**
 * @internal
 */
async function postAsync(url, body, authRequestInfo) {
    return authRequest(authRequestInfo, async (config) => {
        const postConfig = {
            ...config,
            body,
            method: "POST",
        };
        return (0, isomorphic_fetch_1.default)(url, postConfig);
    });
}
exports.postAsync = postAsync;
/**
 * @internal
 */
async function unauthPostAsync(url, body) {
    return safeRequestCore(async () => {
        return (0, isomorphic_fetch_1.default)(url, { body, method: "POST" });
    });
}
exports.unauthPostAsync = unauthPostAsync;
async function authRequest(authRequestInfo, requestCallback) {
    return (0, odspAuth_js_1.authRequestWithRetry)(authRequestInfo, async (config) => safeRequestCore(async () => requestCallback(config)));
}
async function safeRequestCore(requestCallback) {
    let response;
    try {
        response = await requestCallback();
    }
    catch (error) {
        if (error?.response?.status) {
            response = error.response;
        }
        else {
            throw error;
        }
    }
    return response;
}
//# sourceMappingURL=odspRequest.js.map